<?php
/**
 * This is the entrypoint for the locrMAPS WordPress plugin.
 *
 * @package locrMAPS
 */

declare(strict_types=1);

namespace Locr\WordPress\Plugin\LocrMaps\DDD\ValueObjects\OnlineMap;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * This class is responsible for the icon name.
 *
 * @property-read string $value The raw value.
 */
final class Style implements \Stringable {
	public const DEFAULT = '4203';

	/**
	 * The id value of the icon.
	 *
	 * @var string
	 */
	private readonly string $value;

	/**
	 * The constructor.
	 *
	 * @param mixed $value The id of the icon.
	 * @throws \InvalidArgumentException If the id is not numeric or less than 1.
	 */
	public function __construct( mixed $value = self::DEFAULT ) {
		if ( ! is_string( $value ) ) {
			throw new \InvalidArgumentException( 'The name must be a string.' );
		}

		$value = trim( $value );
		if ( empty( $value ) ) {
			$value = self::DEFAULT;
		}

		$this->value = $value;
	}

	/**
	 * The magick getter.
	 *
	 * @param string $name The name of the property.
	 * @throws \InvalidArgumentException If the property does not exist.
	 */
	public function __get( string $name ): mixed {
		return match ( $name ) {
			'value' => $this->value,
			default => throw new \InvalidArgumentException( 'The property "' . esc_html( $name ) . '" does not exist.' ),
		};
	}

	/**
	 * The magick to string method.
	 */
	public function __toString(): string {
		return $this->value;
	}
}
