/**
 * React hook that is used to mark the block wrapper element.
 * It provides all the necessary props like the class name.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/packages/packages-block-editor/#useblockprops
 */
import { useBlockProps } from '@wordpress/block-editor';

/**
 * The save function defines the way in which the different attributes should
 * be combined into the final markup, which is then serialized by the block
 * editor into `post_content`.
 *
 * @param {{
 * 	attributes: {
 * 		height: string,
 * 		width: string
 * 	}
 * }} root0
 * @see https://developer.wordpress.org/block-editor/reference-guides/block-api/block-edit-save/#save
 *
 * @return {Element}      Element to render.
 */
export default function save( { attributes } ) {
	const { width, height, onlinemap } = attributes;

	return (
		<div
			{ ...useBlockProps.save() }
			id={ `locrmaps-container-${ onlinemap }` }
			style={ {
				width: width || '100%',
				height: height || '100%',
				display: 'flex',
			} }
		>
			<locr-map
				id={ `locrmaps-map-${ onlinemap }` }
				style={ {
					width: '100%',
					height: '100%',
					minHeight: '85px',
					minWidth: '240px',
					maxWidth: '100%',
					maxHeight: '100%',
					margin: 'auto',
				} }
			></locr-map>
		</div>
	);
}
